.. _citing:

Цитирование
===========

Если вы использовали pymorphy2 в научных целях,
то будет хорошо, если процитируете следующую
`статью <https://link.springer.com/chapter/10.1007%2F978-3-319-26123-2_31>`_:

::

    Korobov M.: Morphological Analyzer and Generator for Russian and
    Ukrainian Languages // Analysis of Images, Social Networks and Texts,
    pp 320-332 (2015).

Это не обязательно, но автору будет приятно.

BibTeX::

   @incollection{
      year={2015},
      isbn={978-3-319-26122-5},
      booktitle={Analysis of Images, Social Networks and Texts},
      volume={542},
      series={Communications in Computer and Information Science},
      editor={Khachay, Mikhail Yu. and Konstantinova, Natalia and Panchenko, Alexander and Ignatov, Dmitry I. and Labunets, Valeri G.},
      doi={10.1007/978-3-319-26123-2_31},
      title={Morphological Analyzer and Generator for Russian and Ukrainian Languages},
      url={http://dx.doi.org/10.1007/978-3-319-26123-2_31},
      publisher={Springer International Publishing},
      keywords={Morphological analyzer; Russian; Ukrainian; Morphological generator; Open source; OpenCorpora; LanguageTool; pymorphy2; pymorphy},
      author={Korobov, Mikhail},
      pages={320-332},
      language={English}
   }

Препринт статьи доступен для скачивания
на arxiv (`pdf <https://arxiv.org/pdf/1503.07283v1.pdf>`_).
